BuglyConfig class

@author : 于德海 time : 2024/5/8 16:06 desc : Class BuglyConfig is used to configure Bugly,

Constructors

BuglyConfig({required String androidAppId, required String iosAppId, String? channel, bool? debugMode})

Properties

androidAppId → String
androidAppId is the Android Bugly AppId
final
hashCode → int
The hash code for this object.
no setterinherited
iosAppId → String
iosAppId is the IOS Bugly AppId
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
params to Map trans by channel
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited