MethodChannelBuglyPlugin class

An implementation of BuglyPluginPlatform that uses method channels.

Inheritance

Constructors

MethodChannelBuglyPlugin()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
methodGetVersion → String
final
methodInitBugly → String
final
methodReportException → String
final
methodSetUserId → String
final
methodTestNativeCrash → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() → Future<String?>
return now platform version
override
initBugly(BuglyConfig config) → void
init tencent bugly
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportException(String errorMsg, String stackInfo) → void
custom report exception
override
setUserId(String userId) → void
override
testNativeCrash() → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited